"""
datazen - A target-type for grouping other target-tasks together.
"""

# built-in
from typing import List, Tuple

# internal
from datazen.environment.task import TaskEnvironment


class GroupEnvironment(TaskEnvironment):
    """Leverages a task-environment to group tasks together."""

    def __init__(self):
        """Add the 'renders' handle."""

        super().__init__()
        self.handles["groups"] = self.valid_group

    def valid_group(
        self,
        entry: dict,
        _: str,
        dep_data: dict = None,
        deps_changed: List[str] = None,
    ) -> Tuple[bool, bool]:
        """Stub task to group other tasks."""

        if dep_data is not None:
            self.task_data["groups"][entry["name"]] = dep_data
        return (True, bool(deps_changed))



from cerberus import Validator
from datazen.classes.valid_dict import ValidDict as ValidDict
from datazen.load import load_dir as load_dir
from typing import Any, Dict, Iterator, List

LOG: Any

def load(directories: List[str], require_all: bool = ..., loaded_list: List[str] = ..., hashes: Dict[str, dict] = ...) -> dict: ...
def add_global_schemas(schema_data: Dict[str, dict]) -> None: ...
def remove_global_schemas(schema_data: Dict[str, dict]) -> None: ...
def load_types(directories: List[str], loaded_list: List[str] = ..., hashes: Dict[str, dict] = ...) -> Dict[str, dict]: ...
def validate(schema_data: Dict[str, Validator], data: dict) -> bool: ...
def inject_custom_schemas(schema_data: Dict[str, dict], should_inject: bool = ...) -> Iterator[None]: ...



from datazen.load import load_dir as load_dir
from typing import Dict, List

def load(directories: List[str], variable_data: dict = ..., loaded_list: List[str] = ..., hashes: Dict[str, dict] = ...) -> dict: ...



from datazen import ROOT_NAMESPACE as ROOT_NAMESPACE
from datazen.enums import DataType as DataType
from datazen.environment.base import LOADTYPE as LOADTYPE
from datazen.environment.schema import SchemaEnvironment as SchemaEnvironment
from datazen.environment.variable import VariableEnvironment as VariableEnvironment
from typing import Any, List

LOG: Any

class ConfigEnvironment(VariableEnvironment, SchemaEnvironment):
    configs_valid: bool
    def __init__(self) -> None: ...
    def load_configs(self, cfg_loads: LOADTYPE = ..., var_loads: LOADTYPE = ..., sch_loads: LOADTYPE = ..., sch_types_loads: LOADTYPE = ..., name: str = ...) -> dict: ...
    def add_config_dirs(self, dir_paths: List[str], rel_path: str = ..., name: str = ..., allow_dup: bool = ...) -> int: ...



from datazen.paths import get_file_ext as get_file_ext
from typing import Any, List, TextIO, Tuple

LOG: Any

def get_json_data(data_file: TextIO) -> Tuple[dict, bool]: ...
def get_yaml_data(data_file: TextIO) -> Tuple[dict, bool]: ...
def load_stream(data_stream: TextIO, data_path: str) -> Tuple[dict, bool]: ...
def dedup_dict_lists(data: dict) -> dict: ...
def merge_dicts(dicts: List[dict], expect_overwrite: bool = ...) -> dict: ...
def merge(dict_a: dict, dict_b: dict, path: List[str] = ..., expect_overwrite: bool = ...) -> dict: ...
def load(data_path: str, variables: dict, dict_to_update: dict, expect_overwrite: bool = ..., is_template: bool = ...) -> Tuple[dict, bool]: ...
def get_hash(data: str, encoding: str = ...) -> str: ...
def get_file_hash(path: str) -> str: ...
def set_file_hash(hashes: dict, path: str, set_new: bool = ...) -> bool: ...



# =====================================
# generator=datazen
# version=1.7.9
# hash=7370e5c6c93e3fd5bdc9211e4fd1c673
# =====================================

"""
datazen - Useful defaults and other package metadata.
"""

PKG_NAME = "datazen"
VERSION = "1.7.10"
DESCRIPTION = "Compile and render schema-validated configuration data."

DEFAULT_TYPE = "yaml"
DEFAULT_MANIFEST = f"manifest.{DEFAULT_TYPE}"
DEFAULT_DIR = f"{PKG_NAME}-out"
CACHE_SUFFIX = "_cache"
GLOBAL_KEY = "global"
ROOT_NAMESPACE = "__root__"



from datazen.environment.task import TaskEnvironment as TaskEnvironment, get_path as get_path
from typing import Any, List, Tuple

LOG: Any

class CommandEnvironment(TaskEnvironment):
    def __init__(self) -> None: ...
    def valid_command(self, entry: dict, _: str, __: dict = ..., deps_changed: List[str] = ...) -> Tuple[bool, bool]: ...
